CustomerIOConfig class

Constructors

CustomerIOConfig({required String cdpApiKey, String? migrationSiteId, Region? region, CioLogLevel? logLevel, bool? autoTrackDeviceAttributes, bool? trackApplicationLifecycleEvents, String? apiHost, String? cdnHost, int? flushAt, int? flushInterval, ScreenView? screenViewUse, InAppConfig? inAppConfig, PushConfig? pushConfig, LocationConfig? locationConfig, GeofenceConfig? geofenceConfig, CustomerIOConfigIos? iosConfig, LiveActivitiesConfig? liveNotificationsConfig})

Properties

apiHost → String?
final
autoTrackDeviceAttributes → bool?
final
cdnHost → String?
final
cdpApiKey → String
final
flushAt → int?
final
flushInterval → int?
final
geofenceConfig → GeofenceConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
inAppConfig → InAppConfig?
final
iosConfig → CustomerIOConfigIos?
final
liveNotificationsConfig → LiveActivitiesConfig?
final
locationConfig → LocationConfig?
final
logLevel → CioLogLevel?
final
migrationSiteId → String?
final
pushConfig → PushConfig
final
region → Region?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenViewUse → ScreenView?
final
source → String
final
trackApplicationLifecycleEvents → bool?
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited