locationMode property
How the module acquires the device location it needs for geofencing. Defaults to GeofenceLocationMode.automatic.
Implementation
final GeofenceLocationMode locationMode;
How the module acquires the device location it needs for geofencing. Defaults to GeofenceLocationMode.automatic.
final GeofenceLocationMode locationMode;