CustomerIOConfigIos class

iOS-only SDK configuration; has no effect on Android.

Constructors

CustomerIOConfigIos({bool? allowBackgroundDelivery})

Properties

allowBackgroundDelivery bool?
Whether geofence transitions are delivered in real time on a background cold-wake. When unset, defaults on if the geofence module is added, off otherwise.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited