allowBackgroundDelivery property

bool? allowBackgroundDelivery
final

Whether geofence transitions are delivered in real time on a background cold-wake. When unset, defaults on if the geofence module is added, off otherwise.

Implementation

final bool? allowBackgroundDelivery;