GeofenceLocationMode enum

How the geofence module acquires the device location it needs for geofencing. Location acquired for geofencing is never sent to analytics.

Inheritance
Available extensions

Values

automatic → const GeofenceLocationMode

SDK acquires a fix itself when geofencing needs one and none is available (default).

const GeofenceLocationMode(rawValue: 'AUTOMATIC')
manual → const GeofenceLocationMode

Host drives it via CustomerIO.geofence.refreshFromCurrentLocation().

const GeofenceLocationMode(rawValue: 'MANUAL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GeofenceLocationMode>
A constant List of the values in this enum, in order of their declaration.