PushClickBehaviorAndroid enum

Enum to specify the click behavior of push notification for Android

Inheritance
Available extensions

Values

resetTaskStack → const PushClickBehaviorAndroid
const PushClickBehaviorAndroid(rawValue: 'RESET_TASK_STACK')
activityPreventRestart → const PushClickBehaviorAndroid
const PushClickBehaviorAndroid(rawValue: 'ACTIVITY_PREVENT_RESTART')
activityNoFlags → const PushClickBehaviorAndroid
const PushClickBehaviorAndroid(rawValue: 'ACTIVITY_NO_FLAGS')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PushClickBehaviorAndroid>
A constant List of the values in this enum, in order of their declaration.