InAppEvent class

Class that holds information about the InAppEvent.

Constructors

InAppEvent({required EventType eventType, required InAppMessage message, String? actionValue, String? actionName})
Constructor for the InAppEvent.
InAppEvent.fromMap(EventType type, Map<String?, dynamic> map)
Constructor for creating an InAppEvent from a map.

Properties

actionName → String?
The name of the action taken on the InAppMessage.
final
actionValue → String?
The value of the action taken on the InAppMessage.
final
eventType → EventType
The type of event.
final
hashCode → int
The hash code for this object.
no setterinherited
message → InAppMessage
The InAppMessage object.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited