InAppMessage class

Constructors

InAppMessage({required String messageId, String? deliveryId})

Properties

deliveryId → String?
Optional identifier for the delivery of this message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → String
Unique identifier for the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited