CustomerIOLiveActivitiesMethodChannel class
An implementation of CustomerIOLiveActivitiesPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- CustomerIOLiveActivitiesPlatform
- CustomerIOLiveActivitiesMethodChannel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
end(
String activityId, {LiveActivityPayload? payload}) → Future< void> -
Ends a running Live Activity. Ending an unknown/already-ended id is a no-op.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
LiveActivityPayload payload) → Future< String> -
Starts a Live Activity and returns its activity id.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String activityId, LiveActivityPayload payload) → Future< void> -
Updates a running Live Activity with the full desired state.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited