InAppMessage class

Represents an in-app message with its metadata

Constructors

InAppMessage({required String messageId, String? deliveryId, String? elementId})
Creates an in-app message instance
const

Properties

deliveryId → String?
The delivery/campaign identifier (optional)
final
elementId → String?
The element identifier for inline messages (optional)
final
hashCode → int
The hash code for this object.
no setteroverride
messageId → String
The unique identifier for the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override