CustomerIOMessagingInAppMethodChannel class

An implementation of CustomerIOMessagingInAppPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
inbox → NotificationInbox
Access to the notification inbox for managing inbox messages
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissMessage() → void
override
getMessages({String? topic}) → Future<List<InboxMessage>>
override
markInboxMessageDeleted({required InboxMessage message}) → void
override
markInboxMessageOpened({required InboxMessage message}) → void
override
markInboxMessageUnopened({required InboxMessage message}) → void
override
messages({String? topic}) → Stream<List<InboxMessage>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColorScheme(CioColorScheme colorScheme) → void
Overrides the color scheme used to render in-app messages.
override
setInboxEventListener(InboxEventListener? listener) → void
Registers (or clears) the global inbox event listener.
override
subscribeToEventsListener(void onEvent(InAppEvent)) → StreamSubscription
Method to subscribe to the In-App event listener.
override
toString() → String
A string representation of this object.
inherited
trackInboxMessageClicked({required InboxMessage message, String? actionName}) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited