NotificationInbox class

Manages inbox messages for the current user.

Inbox messages are persistent messages that users can view, mark as read/unread, and delete. Messages are automatically fetched and kept in sync for identified users.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMessages({String? topic}) Future<List<InboxMessage>>
Retrieves inbox messages asynchronously.
markMessageDeleted(InboxMessage message) → void
Marks an inbox message as deleted. Removes the message from local state and syncs with the server.
markMessageOpened(InboxMessage message) → void
Marks an inbox message as opened/read. Updates local state immediately and syncs with the server.
markMessageUnopened(InboxMessage message) → void
Marks an inbox message as unopened/unread. Updates local state immediately and syncs with the server.
messages({String? topic}) Stream<List<InboxMessage>>
Returns a stream that emits inbox messages whenever they change.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trackMessageClicked(InboxMessage message, {String? actionName}) → void
Tracks a click event for an inbox message. Sends metric event to data pipelines to track message interaction.

Operators

operator ==(Object other) bool
The equality operator.
inherited