getMessages method

Future<List<InboxMessage>> getMessages({
  1. String? topic,
})

Retrieves inbox messages asynchronously.

@param topic Optional topic filter. If provided, only messages that have this topic in their topics list are returned. If null, all messages are returned. @return Future that resolves to a list of inbox messages

Implementation

Future<List<InboxMessage>> getMessages({String? topic}) {
  return _platform.getMessages(topic: topic);
}