markMessageDeleted method
Marks an inbox message as deleted. Removes the message from local state and syncs with the server.
@param message The inbox message to mark as deleted
Implementation
void markMessageDeleted(InboxMessage message) {
_platform.markInboxMessageDeleted(message: message);
}