GeofenceConfig class
Configuration for the optional Geofence module.
Providing a GeofenceConfig opts the app into geofence monitoring; this also enables the Location module, which geofence depends on.
Constructors
- GeofenceConfig({GeofenceLocationMode locationMode = GeofenceLocationMode.automatic})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationMode → GeofenceLocationMode
-
How the module acquires the device location it needs for geofencing.
Defaults to GeofenceLocationMode.automatic.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited