LocationTrackingMode enum

Location tracking mode for the CustomerIO Location module.

Inheritance
Available extensions

Values

off → const LocationTrackingMode

Location tracking is disabled. All location operations no-op.

const LocationTrackingMode(rawValue: 'OFF')
manual → const LocationTrackingMode

Host app controls when location is captured (default).

const LocationTrackingMode(rawValue: 'MANUAL')
onAppStart → const LocationTrackingMode

SDK auto-captures location once per app launch when the app becomes active.

const LocationTrackingMode(rawValue: 'ON_APP_START')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocationTrackingMode>
A constant List of the values in this enum, in order of their declaration.