CustomerIOLiveActivitiesPlatform class abstract
The interface that implementations of the Live Activities module must implement.
Live Activities (iOS) / Live Notifications (Android) are exposed here. There is intentionally no lifecycle event listener/stream, as neither native SDK exposes one.
- Inheritance
-
- Object
- PlatformInterface
- CustomerIOLiveActivitiesPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
end(
String activityId, {LiveActivityPayload? payload}) → Future< void> - Ends a running Live Activity. Ending an unknown/already-ended id is a no-op.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
LiveActivityPayload payload) → Future< String> - Starts a Live Activity and returns its activity id.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String activityId, LiveActivityPayload payload) → Future< void> - Updates a running Live Activity with the full desired state.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CustomerIOLiveActivitiesPlatform
-
getter/setter pair