CustomerIOMessagingInAppPlatform class abstract
The default instance of CustomerIOMessagingInAppPlatform to use
Platform-specific plugins should override this with their own platform-specific class that extends CustomerIOMessagingInAppPlatform when they register themselves.
Defaults to CustomerIOMessagingInAppMethodChannel
- Inheritance
-
- Object
- PlatformInterface
- CustomerIOMessagingInAppPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inbox → NotificationInbox
-
Access to the notification inbox for managing inbox messages
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dismissMessage(
) → void -
getMessages(
{String? topic}) → Future< List< InboxMessage> > -
markInboxMessageDeleted(
{required InboxMessage message}) → void -
markInboxMessageOpened(
{required InboxMessage message}) → void -
markInboxMessageUnopened(
{required InboxMessage message}) → void -
messages(
{String? topic}) → Stream< List< InboxMessage> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribeToEventsListener(
void onEvent(InAppEvent)) → StreamSubscription -
toString(
) → String -
A string representation of this object.
inherited
-
trackInboxMessageClicked(
{required InboxMessage message, String? actionName}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CustomerIOMessagingInAppPlatform
-
getter/setter pair